﻿/*

   Copyright 2021 Esri

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

   See the License for the specific language governing permissions and
   limitations under the License.

*/
using ArcGIS.Core.CIM;
using ArcGIS.Core.Data;
using ArcGIS.Core.Geometry;
using ArcGIS.Desktop.Catalog;
using ArcGIS.Desktop.Core;
using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Extensions;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Layouts;
using ArcGIS.Desktop.Mapping;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace WhatsNew
{
  internal class DefaultMapTool : MapTool
  {
    public DefaultMapTool()
    {
      IsSketchTool = true;
      SketchType = SketchGeometryType.Rectangle;
      SketchOutputMode = SketchOutputMode.Map;
    }

    protected override Task OnToolActivateAsync(bool active)
    {
      return base.OnToolActivateAsync(active);
    }

    protected override async Task<bool> OnSketchCompleteAsync(Geometry geometry)
    {
      var layer = MapView.Active.Map.GetLayersAsFlattenedList().FirstOrDefault(l => l.Name == "Line2") as BasicFeatureLayer;
      if (layer == null)
        return false;

      bool isEditingEnabled = Project.Current.IsEditingEnabled;

      var (result, error) = await QueuedTask.Run(() =>
      {
        var features = MapView.Active.GetFeatures(geometry);

        // find the features from a specified layer
        if (features.ContainsKey(layer))
        {
          var atts = new Dictionary<string, object>();
          atts.Add("UpdatedBy", Environment.UserName);

          var op = new EditOperation();
          op.Name = "Update attributes";

          foreach (var oid in features[layer])
          {
            op.Modify(layer, oid, atts);
          }

          var success = op.Execute();
          var msg = op.ErrorMessage;

          return Tuple.Create(success, msg);
        }

        return Tuple.Create(false, "No features from \"Line2\" identified.");
      });

      if (!result)
        MessageBox.Show(error);

      return result;
    }
  }
}
